# == Class: drupal
#
# Installation d'un environnement LAMP avec Drupal7 
#
# === Parameters
#
# Les paramètres $1 $2 de /tmp/mysql sont respectivement le mot de passe root mysql et le mot de passe du compte drupal7 mysql données en paramètres dans les userdatas du script de déploiement drupal.php disponible sur le GitHub Ikoula
#
#
# === Authors
#
# Author LaurentH Ikoula contribATikoula.com
#
# === Copyright
#
# Copyright 2013 LaurentH Ikoula.
#
class lamp::install {
	exec { 'apt-get update':
		command => "apt-get update",
		path => "/usr/bin",
	} 
	Package { ensure => "installed" }
	$enhancers = [ "apache2", "mysql-server", "libapache2-mod-php5", "php5-mysql", "php5-gd" ]
	package { $enhancers: }
    	file { "/etc/apache2/sites-available/drupal" :
        source => "/etc/puppet/modules/drupal/files/etc.apache2.sites-available.drupal",
	ensure => "present",
        owner   => "root",
        group   => "root",
        require => Package['apache2'],
        mode    => 0644
    	}
}
class drupal::install {
	exec { 'drupal':
		command => 'wget -P /var/www/ http://ftp.drupal.org/files/projects/drupal-7.23.tar.gz && tar -xvzf /var/www/drupal-7.23.tar.gz -C /var/www/ && mv /var/www/drupal-7.23 /var/www/drupal && chown -R www-data.www-data /var/www/drupal/ && rm -rf /var/www/drupal-7.23.tar.gz',
		path => [ "/usr/bin", "/bin" ],
		require => Class["lamp::install"],
	}
}
class apache::vhost {
	exec { 'drupalvhost':
		command => 'a2ensite drupal && a2dissite default',
		path => [ "/usr/sbin", "/usr/bin" ],
		require => [Class["lamp::install"],
				Class["drupal::install"],
				]
	}
}
class apache::service {
	exec { 'httpreload':
		command => '/etc/init.d/apache2 reload',
		require    => Class["apache::vhost"],
        }
}
class mysql::rootpw {
        exec { 'rootpw':
                command => 'mysqladmin -u root password `awk \'{print $1}\' /tmp/mysql`',
                path => '/usr/bin',
                require => Class["lamp::install"],
                logoutput => on_failure
        }
}
class mysql::drupalbdd {
        exec { 'drupalbdd':
                command => 'mysql -u root -p`awk \'{print $1}\' /tmp/mysql` -e "CREATE DATABASE drupal7;"',
                path => '/usr/bin',
                require => [Class["lamp::install"],
                                Class["mysql::rootpw"],
                                ]
        }
}
class mysql::drupalbdduser {
	 exec { 'drupaluser':
                command => 'mysql -u root -p`awk \'{print $1}\' /tmp/mysql` -e "CREATE USER \'drupal7\'@\'localhost\' IDENTIFIED BY \'`awk \'{print $2}\' /tmp/mysql`\';"',
                path => [ "/usr/bin", "/bin" ],
                require => [Class["lamp::install"],
                                Class["mysql::rootpw"],
                                ]
        }
}
class mysql::drupalbddpriv {
	exec { 'drupalpriv':	
		command => 'mysql -u root -p`awk \'{print $1}\' /tmp/mysql` -e "GRANT ALL PRIVILEGES ON drupal7.* TO \'drupal7\'@\'localhost\';" && rm -f /tmp/mysql',
		path => [ "/usr/bin", "/bin" ], 
		require => Class["mysql::drupalbdduser"],
		logoutput => on_failure
	}
}
class mysql::service {
        service { "mysql" :
                        ensure     => "running",
                        enable     => "true",
                        hasrestart => "true",
                        hasstatus => "true",
                        require    => [Class["lamp::install"],
						Class["mysql::drupalbdduser"],
					]
        }
}
class drupal {
        include lamp::install, drupal::install, apache::vhost, apache::service, mysql::rootpw, mysql::drupalbdd, mysql::drupalbdduser, mysql::drupalbddpriv, mysql::service
}
